| calculate | R Documentation |
Calculate results using given data on a row basis
calculate(data)
data |
Data frame used for calculation. Needs to contain 5 columns named a-e (see |
Input data frame with additional column res that contains calculation results for rows
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.