data: Example data set for Senior Software Developer recruitment...

dataR Documentation

Example data set for Senior Software Developer recruitment task

Description

This data set simulates data that could be provided for some analytics work. You can assume that each row represents some data entry (e.g. single day), and each column is some variable that affects calculations of results (see calculate function for more info).

Usage

data

Format

A data frame with 30 rows and 5 variables:

a

variable a, range 10000-50000

b

variable b, range 50-100

c

variable c, range 10-20

d

variable d, range 1-5

e

variable e, range 1-2


EdwardJGillian/AnGil documentation built on April 19, 2022, 11:14 a.m.