| data | R Documentation |
This data set simulates data that could be provided for some analytics work.
You can assume that each row represents some data entry (e.g. single day),
and each column is some variable that affects calculations of results
(see calculate function for more info).
data
A data frame with 30 rows and 5 variables:
variable a, range 10000-50000
variable b, range 50-100
variable c, range 10-20
variable d, range 1-5
variable e, range 1-2
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.